#  RustDesk-Server auf Portainer installieren


##  Voraussetzungen
- Ein Server mit **Docker** und **Portainer** installiert
- Ein öffentlicher oder privater **Domainname** (optional, aber empfohlen)
- Ports **21115-21119** in der Firewall freigegeben

---

## Installation

### Erstelle einen neuen Stack in Portainer
1. **Melde dich bei Portainer an** und navigiere zu **Stacks**.
2. Klicke auf **"Add Stack"**.
3. Setze als Namen z.B. `rustdesk-server`.
4. Füge folgenden Docker-Compose-Code in das **Web-Editor-Feld** ein:
```yaml

services:
  rust_desk_hbbs:
    container_name: rust_desk_hbbs
    image: rustdesk/rustdesk-server
    restart: always
    ports:
      - "21114:21114"
      - "21115:21115"
      - "21116:21116"
      - "21116:21116/udp"
      - "21118:21118"
    command: ["hbbs", "-r", "${HOST}", "-m", "demo"]
    volumes:
      - rust_desk_hbbs_data:/root
    networks:
      - rust_desk_net
  
  rust_desk_hbbr:
    container_name: rust_desk_hbbr
    image: rustdesk/rustdesk-server
    restart: always
    ports:
      - "21117:21117"
      - "21119:21119"
    command: ["hbbr", "-m", "demo"]
    volumes:
      - rust_desk_hbbr_data:/root
    networks:
      - rust_desk_net

volumes:
  rust_desk_hbbs_data:
    name: rust_desk_hbbs_data
  rust_desk_hbbr_data:
    name: rust_desk_hbbr_data

networks:
  rust_desk_net:
    driver: bridge
```
5. Umgebungs variablen die Erstellt werden müssen
| Key | Value |
|---------|--------|
| Host | ip auf der hbbs dienst erreichbar sein soll" |



###  Erstelle den Stack
1. **Scrolle nach unten** und klicke auf **"Deploy the Stack"**.
2. Warte einige Sekunden, bis die Container gestartet wurden.

---

##  Konfiguration

###  Prüfe, ob der Server läuft
Gib folgendes auf der **Linux-Shell** deines Servers ein:

```sh
docker ps
```
Falls `hbbs` und `hbbr` als **running** angezeigt werden, läuft der Server.

###  Ports in der Firewall freigeben (falls nicht bereits geschehen)
Falls dein Server eine Firewall nutzt, stelle sicher, dass folgende Ports offen sind:

```sh
sudo ufw allow 21115:21119/tcp
sudo ufw allow 21116:21117/udp
sudo ufw reload
```

Falls du **firewalld** nutzt:

```sh
sudo firewall-cmd --add-port=21115-21119/tcp --permanent
sudo firewall-cmd --add-port=21116-21117/udp --permanent
sudo firewall-cmd --reload
```

---

##  Nutzung

### RustDesk-Client mit eigenem Server verbinden
1. Öffne den **RustDesk-Client**.
2. Gehe zu **Einstellungen > Netzwerk > Relay/ID-Server**.
3. Trage die **IP-Adresse oder Domain** deines Servers ein.
4. Speichere die Einstellungen.

Nun kannst du RustDesk mit deinem eigenen Server nutzen! 🎉

---

##  Fehlerbehebung

| Problem | Lösung |
|---------|--------|
| Container startet nicht | Prüfe `docker logs hbbs` oder `docker logs hbbr` |
| Verbindungsprobleme | Stelle sicher, dass die Ports geöffnet sind |
| RustDesk-Client kann sich nicht verbinden | Prüfe die IP-Adresse und Firewall-Einstellungen |

